@@ -27,6 +27,7 @@ $message = array(
     'lang' => 'en',
     'strLang' => 'English',
 
+    'descAllow_clear_text_frontend_auth' => 'If on, allow the Pgpool-II to use clear-text-password authentication with frontend clients',
     'descAllow_multiple_failover_requests_from_node' => 'If on, a single Pgpool-II node can cast multiple votes for the failover',
     'descAllow_sql_comments' => 'If on, ignore SQL comments when judging if load balance or query cache is possible',
     'descApp_name_redirect_preference_list' => '"application name:node id" pairs to specify the node id when the application is used',
@@ -39,9 +40,9 @@ $message = array(
     'descBackend_socket_dir' => 'The socket directory PostgreSQL could connect',
     'descBackend_weight' => 'Load balance weight when pgpool is running in the state of load balance mode',
     'descBackend_data_directory' => 'PostgreSQL database directory',
-    'descDelegate_IP' => 'The virtual IP address (VIP) of pgpool-II ',
     'descBlack_function_list' => 'Comma separated functions which write to database',
     'descBlack_memqcache_table_list' => 'Comma separated list of table names not to be cached',
+    'descBlack_query_pattern_list' => 'Semicolon separated list of SQL patterns not to be load balanced',
     'descCheck_temp_table' => 'If on, enable temporary table check in SELECT statements',
     'descCheck_unlogged_table' => 'If on, enable unlogged table check in SELECT statements.',
     'descChild_life_time' => 'Life of an idle child process in seconds',
@@ -55,9 +56,12 @@ $message = array(
     'descConnection_life_time' => 'Life time for each idle connection in seconds',
     'descConnect_timeout' => 'Timeout value in milliseconds before giving up connecting to backend using connect() system call',
     'descDatabase_redirect_preference_list' => '"database name:node id" pairs to specify the node id when connecting to the database',
+    'descDebug_level' => 'Debug message verbosity level',
     'descDelay_threshold' => 'If the standby server delays more than delay_threshold, '.
                              'any query goes to the primary only',
-    'descDebug_level' => 'Debug message verbosity level',
+    'descDelegate_IP' => 'The virtual IP address (VIP) of pgpool-II ',
+    'descDetach_false_primary' => 'If on, detach false primary node',
+    'descDisable_load_balance_on_write' => 'Specify load balance behavior when write query is issued',
     'descEnable_pool_hba' => 'Use host-based authentication',
     'descEnable_query_cache' => 'Perform query cache',
     'descFailover_command' => 'Command to execute when detaching a node',
@@ -67,6 +71,7 @@ $message = array(
     'descFailover_require_consensus' => 'If on, Pgpool-II will perform the degenerate/failover on a backend node if the watchdog quorum exists',
     'descFailover_when_quorum_exists' => 'If on, Pgpool-II will perform the degenerate/failover on backend node if the quorum exists',
     'descFail_over_on_backend_error' => 'Fail over when socket communication error to backend occurs',
+    'descFailover_on_backend_error' => 'Fail over when socket communication error to backend occurs',
     'descFollow_master_command' => 'Command to run only after a master failover',
     'descHeartbeat_destination' => 'The destination of heartbeat signals. Specify by hostname or IP address.',
     'descHeartbeat_destination_port' => 'The port number of the destination of heartbeat signals.',
@@ -92,6 +97,7 @@ $message = array(
     'descListen_backlog_multiplier' => 'The number of preforked pgpool-II server processes',
     'descLoad_balance_mode' => 'Perform load balancing for SELECT',
     'descLobj_lock_table' => 'Specifies table name lock used when rewriting lo_create in replication mode',
+    'descLog_client_messages' => 'If true, print client messages to the log',
     'descLog_connections' => 'If true, incoming connections will be printed to the log',
     'descLog_destination' => 'Where to log',
     'descLog_error_verbosity' => 'The amount of detail emitted for each message that is logged',
