@@ -27,6 +27,7 @@ $message = array(
     'lang' => 'ja',
     'strLang' => '日本語',
 
+    'descAllow_clear_text_frontend_auth' => 'Pgpool-IIがフロントエンドクライアントとクリアテキストパスワード認証を許可',
     'descAllow_multiple_failover_requests_from_node' => '単一のPgpool-IIノードが複数のフェイルオーバ投票ができるどうか',
     'descAllow_sql_comments' => '負荷分散やクエリキャッシュができるかどうかの判定の際に、SQLコメントを無視するかどうか',
     'descApp_name_redirect_preference_list' => 'アプリケーション名によって負荷分散をしたいノード番号を、"アプリケーション名:ノード番号"で指定',
@@ -41,6 +42,7 @@ $message = array(
     'descBackend_data_directory' => 'PostgreSQLサーバのデータベースディレクトリ',
     'descBlack_function_list' => 'データベースに書き込みを行なうカンマ区切りの関数のリスト',
     'descBlack_memqcache_table_list' => 'SELECT結果をキャッシュしたくないテーブル名のカンマ区切りのリスト',
+    'descBlack_query_pattern_list' => '負荷分散を行わないセミコロン区切りのSQLパターンリスト',
     'descCheck_temp_table' => '一時テーブルかどうかをチェック',
     'descCheck_unlogged_table' => 'unloggedテーブルかどうかをチェック',
     'descChild_life_time' => 'pgpoolの子プロセスの寿命',
@@ -56,6 +58,8 @@ $message = array(
     'descDebug_level' => 'デバッグメッセージの詳細レベル（0は無効）',
     'descDelay_threshold' => '許容するスタンバイサーバの遅延(バイト)',
     'descDelegate_IP' => '仮想 IP アドレス',
+    'descDetach_false_primary' => '不正なプライマリを切り離すかどうか',
+    'descDisable_load_balance_on_write' => '更新クエリが発行された時の負荷分散の振る舞いを指定',
     'descEnable_pool_hba' => 'クライアント認証機能の有無',
     'descEnable_query_cache' => 'クエリキャッシュ機能の有無',
     'descFailover_command' => 'ノード切り離し時に起動するコマンド',
@@ -64,6 +68,7 @@ $message = array(
     'descFailover_require_consensus' => 'クォーラム投票によりフェイルオーバを実行するかどうか',
     'descFailover_when_quorum_exists' => 'クォーラム機能によりフェイルオーバを実行するかどうか',
     'descFail_over_on_backend_error' => 'DBノードへのソケット通信エラー時にフェイルオーバ',
+    'descFailover_on_backend_error' => 'DBノードへのソケット通信エラー時にフェイルオーバ',
     'descFollow_master_command' => 'マスタのフェイルオーバ後に実行するコマンド',
     'descHeartbeat_destination' => 'ハートビート信号の送信先ホスト名または IP アドレス',
     'descHeartbeat_destination_port' => 'ハートビート信号の送信先ポート番号',
@@ -85,6 +90,7 @@ $message = array(
     'descListen_backlog_multiplier' => 'フロントエンドからpgpool-IIへの接続待ち行列の長さ',
     'descLoad_balance_mode' => 'レプリケーションモード時にSELECT文を各ノードにロードバランス',
     'descLobj_lock_table' => 'ラージオブジェクトのレプリケーションでロック管理に使うためのテーブル名',
+    'descLog_client_messages' => 'クライアントメッセージをログに出力',
     'descLog_connections' => '受信した接続のログを出力',
     'descLog_destination' => 'ログの出力先',
     'descLog_error_verbosity' => '出力するログの詳細レベル',
